@@ -16,6 +16,9 @@ def remote(target, arg):
 def update(target, arg):
     target.Package.update()
 
+def upgrade(target, arg):
+    target.Package.upgrade()
+
 def installed(target, arg):
     target.Package.installed(arg)
 
